#!/bin/sh
#
# Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

set -x

if [ -d data ] ; then
	echo "Error: ./data already seems to exist" >&2
	exit 1
fi

mkdir data
mkdir data/qso
mkdir data/tmp

cat > data/config.scm <<DONE
((call . "WX1YZ") ; de station call sign
 (grid . "FN42") ; tx grid locator
 (power . 1500000) ; tx power in mW
 (mode . "SSB") ; tx mode
 )
DONE

cat > data/bands.scm <<DONE
; The following are ITU Region 2 bands
;
; (<band name string> <band name in mm> <start freq Hz> <end freq Hz>)
(("23cm" 230 1240000000 1300000000)
 ("33cm" 330 902000000 928000000)
 ("70cm" 700 420000000 450000000)
 ("1.25m" 1250 219000000 225000000)
 ("2m" 2000 144000000 148000000)
 ("6m" 6000 50000000 54000000)
 ("10m" 10000 28000000 29700000)
 ("12m" 12000 24890000 24990000)
 ("15m" 15000 21000000 21450000)
 ("17m" 17000 18068000 18168000)
 ("20m" 20000 14000000 14350000)
 ("30m" 30000 10100000 10150000)
 ("40m" 40000 7000000 7300000)
 ("60m" 60000 5330500 5406500) ; 60m band is channelized, but this is close enough
 ("80m" 80000 3500000 4000000)
 ("160m" 160000 1800000 2000000)
 ("630m" 630000 472000 479000)
 ("2200m" 2200000 135700 137800))
DONE

curl https://www.country-files.com/bigcty/cty.csv > data/cty.csv
