/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __QSO_IMPL_H
#define __QSO_IMPL_H

#include "qso.h"

enum qso_set {
	QSO_NOT_A_THING, /* no-op / don't set anything */

	QSO_UUID,
	QSO_START,
	QSO_END,
	QSO_COMMENT,

	QSO_TX_STATION_CALL,
	QSO_TX_OPERATOR_CALL,
	QSO_TX_POWER,
	QSO_TX_FREQ,
	QSO_TX_MODE,
	QSO_TX_RST,
	QSO_TX_NAME,
	QSO_TX_QTH,
	QSO_TX_GRID,
	QSO_TX_COUNTRY,
	QSO_TX_STATE,
	QSO_TX_COUNTY,
	QSO_TX_CONTINENT,
	QSO_TX_DXCC,
	QSO_TX_DXCC_CODE,
	QSO_TX_ITU,
	QSO_TX_WAZ,

	QSO_RX_STATION_CALL,
	QSO_RX_OPERATOR_CALL,
	QSO_RX_POWER,
	QSO_RX_FREQ,
	QSO_RX_MODE,
	QSO_RX_RST,
	QSO_RX_NAME,
	QSO_RX_QTH,
	QSO_RX_GRID,
	QSO_RX_COUNTRY,
	QSO_RX_STATE,
	QSO_RX_COUNTY,
	QSO_RX_CONTINENT,
	QSO_RX_DXCC,
	QSO_RX_DXCC_CODE,
	QSO_RX_ITU,
	QSO_RX_WAZ,
};

/*
 * Set a part of the QSO.  This is a lower-level call that's meant to
 * simplify the ADIF parsing code.  The explict setters above should be used
 * instead whenever possible.
 */
extern int qso_set(struct qso *qso, enum qso_set what, char *str);

#endif
